pub struct CurveFlat {
pub id: i32,
pub curve_type: i32,
pub flags: i32,
}Fields
id: i32curve_type: i32flags: i32Trait Implementations
Sourceimpl CopyInsert for CurveFlat
impl CopyInsert for CurveFlat
Sourceimpl<'de> Deserialize<'de> for CurveFlat
impl<'de> Deserialize<'de> for CurveFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl FromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
impl FromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &CurveFlat
impl IntoWasmAbi for &CurveFlat
Sourceimpl IntoWasmAbi for CurveFlat
impl IntoWasmAbi for CurveFlat
Sourceimpl JsonSchema for CurveFlat
impl JsonSchema for CurveFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for CurveFlat
impl OptionIntoWasmAbi for CurveFlat
Sourceimpl RefFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourceimpl Tsify for CurveFlat
impl Tsify for CurveFlat
const DECL: &'static str = "export interface CurveFlat {\n id: number;\n type: number;\n flags: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for CurveFlatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for CurveFlat
impl VectorIntoWasmAbi for CurveFlat
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribeVector for CurveFlat
impl WasmDescribeVector for CurveFlat