pub struct ItemBonusFlat {
pub id: i32,
pub value_0: i32,
pub value_1: i32,
pub value_2: i32,
pub value_3: i32,
pub parent_item_bonus_list_id: i32,
pub bonus_type: i32,
pub order_index: i32,
}Fields
id: i32value_0: i32value_1: i32value_2: i32value_3: i32parent_item_bonus_list_id: i32bonus_type: i32order_index: i32Trait Implementations
Sourceimpl Clone for ItemBonusFlat
impl Clone for ItemBonusFlat
Sourcefn clone(&self) -> ItemBonusFlat
fn clone(&self) -> ItemBonusFlat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CopyInsert for ItemBonusFlat
impl CopyInsert for ItemBonusFlat
Sourceimpl Debug for ItemBonusFlat
impl Debug for ItemBonusFlat
Sourceimpl Default for ItemBonusFlat
impl Default for ItemBonusFlat
Sourcefn default() -> ItemBonusFlat
fn default() -> ItemBonusFlat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ItemBonusFlat
impl<'de> Deserialize<'de> for ItemBonusFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ItemBonusFlat> for JsValuewhere
ItemBonusFlat: Serialize,
impl From<ItemBonusFlat> for JsValuewhere
ItemBonusFlat: Serialize,
Sourcefn from(value: ItemBonusFlat) -> Self
fn from(value: ItemBonusFlat) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
impl FromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &ItemBonusFlatwhere
ItemBonusFlat: Serialize,
impl IntoWasmAbi for &ItemBonusFlatwhere
ItemBonusFlat: Serialize,
Sourceimpl IntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
impl IntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
Sourceimpl JsonSchema for ItemBonusFlat
impl JsonSchema for ItemBonusFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
impl OptionIntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
Sourceimpl RefFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ItemBonusFlat>
type Anchor = SelfOwner<ItemBonusFlat>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ItemBonusFlat
impl Serialize for ItemBonusFlat
Sourceimpl Tsify for ItemBonusFlat
impl Tsify for ItemBonusFlat
const DECL: &'static str = "export interface ItemBonusFlat {\n id: number;\n value_0: number;\n value_1: number;\n value_2: number;\n value_3: number;\n parent_item_bonus_list_id: number;\n type: number;\n order_index: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ItemBonusFlatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
impl VectorIntoWasmAbi for ItemBonusFlatwhere
ItemBonusFlat: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for ItemBonusFlat
impl WasmDescribe for ItemBonusFlat
Sourceimpl WasmDescribeVector for ItemBonusFlat
impl WasmDescribeVector for ItemBonusFlat