pub struct ItemScalingConfigFlat {
pub id: i32,
pub item_offset_curve_id: i32,
pub item_level: i32,
pub required_level: i32,
pub item_squish_era_id: i32,
pub flags: i32,
}Expand description
Flat Midnight item-level scaling config from ItemScalingConfig DBC table.
Fields
id: i32item_offset_curve_id: i32item_level: i32required_level: i32item_squish_era_id: i32flags: i32Trait Implementations
Sourceimpl Clone for ItemScalingConfigFlat
impl Clone for ItemScalingConfigFlat
Sourcefn clone(&self) -> ItemScalingConfigFlat
fn clone(&self) -> ItemScalingConfigFlat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl CopyInsert for ItemScalingConfigFlat
impl CopyInsert for ItemScalingConfigFlat
Sourceimpl Debug for ItemScalingConfigFlat
impl Debug for ItemScalingConfigFlat
Sourceimpl Default for ItemScalingConfigFlat
impl Default for ItemScalingConfigFlat
Sourcefn default() -> ItemScalingConfigFlat
fn default() -> ItemScalingConfigFlat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for ItemScalingConfigFlat
impl<'de> Deserialize<'de> for ItemScalingConfigFlat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ItemScalingConfigFlat> for JsValuewhere
ItemScalingConfigFlat: Serialize,
impl From<ItemScalingConfigFlat> for JsValuewhere
ItemScalingConfigFlat: Serialize,
Sourcefn from(value: ItemScalingConfigFlat) -> Self
fn from(value: ItemScalingConfigFlat) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
impl FromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
impl IntoWasmAbi for &ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
Sourceimpl IntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
impl IntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
Sourceimpl JsonSchema for ItemScalingConfigFlat
impl JsonSchema for ItemScalingConfigFlat
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
impl OptionIntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
Sourceimpl RefFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ItemScalingConfigFlat>
type Anchor = SelfOwner<ItemScalingConfigFlat>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ItemScalingConfigFlat
impl Serialize for ItemScalingConfigFlat
Sourceimpl Tsify for ItemScalingConfigFlat
impl Tsify for ItemScalingConfigFlat
const DECL: &'static str = "/**\n * Flat Midnight item-level scaling config from `ItemScalingConfig` DBC table.\n */\nexport interface ItemScalingConfigFlat {\n id: number;\n item_offset_curve_id: number;\n item_level: number;\n required_level: number;\n item_squish_era_id: number;\n flags: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ItemScalingConfigFlatwhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
impl VectorIntoWasmAbi for ItemScalingConfigFlatwhere
ItemScalingConfigFlat: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for ItemScalingConfigFlat
impl WasmDescribe for ItemScalingConfigFlat