pub struct ItemSetBonus {
pub threshold: i32,
pub spell_id: i32,
pub spec_id: i32,
}Fields
threshold: i32spell_id: i32spec_id: i32Trait Implementations
Sourceimpl Clone for ItemSetBonus
impl Clone for ItemSetBonus
Sourcefn clone(&self) -> ItemSetBonus
fn clone(&self) -> ItemSetBonus
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ItemSetBonus
impl Debug for ItemSetBonus
Sourceimpl<'de> Deserialize<'de> for ItemSetBonus
impl<'de> Deserialize<'de> for ItemSetBonus
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl From<ItemSetBonus> for JsValuewhere
ItemSetBonus: Serialize,
impl From<ItemSetBonus> for JsValuewhere
ItemSetBonus: Serialize,
Sourcefn from(value: ItemSetBonus) -> Self
fn from(value: ItemSetBonus) -> Self
Converts to this type from the input type.
Sourceimpl FromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
impl FromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
Sourceimpl IntoWasmAbi for &ItemSetBonuswhere
ItemSetBonus: Serialize,
impl IntoWasmAbi for &ItemSetBonuswhere
ItemSetBonus: Serialize,
Sourceimpl IntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
impl IntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
Sourceimpl JsonSchema for ItemSetBonus
impl JsonSchema for ItemSetBonus
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl OptionFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
impl OptionFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
Sourceimpl OptionIntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
impl OptionIntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
Sourceimpl PartialEq for ItemSetBonus
impl PartialEq for ItemSetBonus
Sourceimpl RefFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
impl RefFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
Sourcetype Abi = <JsType as RefFromWasmAbi>::Abi
type Abi = <JsType as RefFromWasmAbi>::Abi
The Wasm ABI type references to
Self are recovered from.Sourcetype Anchor = SelfOwner<ItemSetBonus>
type Anchor = SelfOwner<ItemSetBonus>
The type that holds the reference to
Self for the duration of the
invocation of the function that has an &Self parameter. This is
required to ensure that the lifetimes don’t persist beyond one function
call, and so that they remain anonymous.Sourceimpl Serialize for ItemSetBonus
impl Serialize for ItemSetBonus
Sourceimpl Tsify for ItemSetBonus
impl Tsify for ItemSetBonus
const DECL: &'static str = "export interface ItemSetBonus {\n threshold: number;\n spell_id: number;\n spec_id: number;\n}"
const SERIALIZATION_CONFIG: SerializationConfig
type JsType = JsType
fn into_js(&self) -> Result<Self::JsType, Error>where
Self: Serialize,
fn from_js<T>(js: T) -> Result<Self, Error>
Sourceimpl VectorFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
impl VectorFromWasmAbi for ItemSetBonuswhere
Self: DeserializeOwned,
type Abi = <JsType as VectorFromWasmAbi>::Abi
unsafe fn vector_from_abi(js: Self::Abi) -> Box<[Self]>
Sourceimpl VectorIntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
impl VectorIntoWasmAbi for ItemSetBonuswhere
ItemSetBonus: Serialize,
type Abi = <JsType as VectorIntoWasmAbi>::Abi
fn vector_into_abi(vector: Box<[Self]>) -> Self::Abi
Sourceimpl WasmDescribe for ItemSetBonus
impl WasmDescribe for ItemSetBonus
Sourceimpl WasmDescribeVector for ItemSetBonus
impl WasmDescribeVector for ItemSetBonus
impl StructuralPartialEq for ItemSetBonus