pub struct KeyFloorEntry {
pub key_floor: i32,
pub player_condition_id: i32,
}Fields
key_floor: i32player_condition_id: i32Trait Implementations
Sourceimpl Clone for KeyFloorEntry
impl Clone for KeyFloorEntry
Sourcefn clone(&self) -> KeyFloorEntry
fn clone(&self) -> KeyFloorEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for KeyFloorEntry
impl Debug for KeyFloorEntry
Sourceimpl Default for KeyFloorEntry
impl Default for KeyFloorEntry
Sourcefn default() -> KeyFloorEntry
fn default() -> KeyFloorEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for KeyFloorEntry
impl<'de> Deserialize<'de> for KeyFloorEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for KeyFloorEntry
impl JsonSchema for KeyFloorEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for KeyFloorEntry
impl RefUnwindSafe for KeyFloorEntry
impl Send for KeyFloorEntry
impl Sync for KeyFloorEntry
impl Unpin for KeyFloorEntry
impl UnsafeUnpin for KeyFloorEntry
impl UnwindSafe for KeyFloorEntry