pub struct LearnSpell {
pub learn_spell_id: i32,
pub overrides_spell_id: i32,
}Fields
learn_spell_id: i32overrides_spell_id: i32Trait Implementations
Sourceimpl Clone for LearnSpell
impl Clone for LearnSpell
Sourcefn clone(&self) -> LearnSpell
fn clone(&self) -> LearnSpell
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for LearnSpell
impl Debug for LearnSpell
Sourceimpl<'de> Deserialize<'de> for LearnSpell
impl<'de> Deserialize<'de> for LearnSpell
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LearnSpell
impl JsonSchema for LearnSpell
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for LearnSpell
impl PartialEq for LearnSpell
Sourceimpl Serialize for LearnSpell
impl Serialize for LearnSpell
impl StructuralPartialEq for LearnSpell