pub struct TrackedAffixEntry {
pub keystone_affix_id: i32,
pub bonus_rating: i32,
}Fields
keystone_affix_id: i32bonus_rating: i32Trait Implementations
Sourceimpl Clone for TrackedAffixEntry
impl Clone for TrackedAffixEntry
Sourcefn clone(&self) -> TrackedAffixEntry
fn clone(&self) -> TrackedAffixEntry
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for TrackedAffixEntry
impl Debug for TrackedAffixEntry
Sourceimpl Default for TrackedAffixEntry
impl Default for TrackedAffixEntry
Sourcefn default() -> TrackedAffixEntry
fn default() -> TrackedAffixEntry
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for TrackedAffixEntry
impl<'de> Deserialize<'de> for TrackedAffixEntry
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for TrackedAffixEntry
impl JsonSchema for TrackedAffixEntry
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for TrackedAffixEntry
impl RefUnwindSafe for TrackedAffixEntry
impl Send for TrackedAffixEntry
impl Sync for TrackedAffixEntry
impl Unpin for TrackedAffixEntry
impl UnsafeUnpin for TrackedAffixEntry
impl UnwindSafe for TrackedAffixEntry